# samdasoo-content

![image](https://github.com/dMario24/samdasoo-content/assets/134017660/76e04c58-2d31-4771-99ab-ca3988707490)

- 이 프로그램은 삼다수의 주요 성분 지표를 알려줍니다.

### 사용법
```bash
$ pip install samdasoo-content

$ python
>>> import samdasoo_content.content as sam
>>> sam.k()
1.5
>>> sam.ca()
2.5
>>> 
```
